@@ -3,7 +3,7 @@ irm_h<-function(relyrs=NULL,recapyrs=NULL,N=NULL,recapharv=NULL,lambda=NULL,phi=
       Fp<-rep(initial[1],length(Fyr))
       Mp<-rep(initial[2],length(Myr))  
 ### Error Messages
-    if(class(recapharv)!="matrix") stop("recapharv is not a matrix.")
+    if(!is(recapharv,"matrix")) stop("recapharv is not a matrix.")
     if(is.null(relyrs)|is.null(recapyrs)) stop("Missing relyrs or recapyrs.")
     if(is.null(N)) stop("Ns are missing.")
     if(is.null(recapharv)) stop("Missing recovery matrix for harvested fish.")
